@require(hierarchy, klass, children)

    @if hierarchy:
    @for i, parent in enumerate(hierarchy):
    \
    @if i != 0:
    \
    @for j in range (i * 4):
     \
    @end
    ╰──\
    @end
    @parent
    @end
    @for j in range ((len(hierarchy)) * 4):
     \
    @end
    @end
    ╰──@klass.link.title
    @for child in children:
    \
    @for j in range ((len(hierarchy) + 1) * 4):
     \
    @end
    ╰──\
    @child
    @end